Learn R Programming

quollr (version 0.3.13)

glance.highd_vis_model: Generate evaluation metrics for a hex_model object

Description

This function computes evaluation metrics (Error and RMSE) by comparing the high-dimensional data to the predictions obtained from a hex_model object.

Usage

# S3 method for highd_vis_model
glance(x, highd_data, ...)

Value

A tibble contains Error, and MSE values.

Arguments

x

An object of class hex_model generated by fit_highd_model().

highd_data

A data frame or tibble containing the original high-dimensional data with an ID column.

...

Additional arguments (currently unused).

Examples

Run this code
# Assuming 'fit' is a hex_model object and 'scurve' contains the original data:
fit <- fit_highd_model(highd_data = scurve, nldr_data = scurve_umap, b1 = 30,
q = 0.1, hd_thresh = 5)
glance(fit, highd_data = scurve)

Run the code above in your browser using DataLab