Learn R Programming

quollr (version 0.3.13)

find_low_dens_hex: Find low-density Hexagons

Description

This function identifies hexagons with low density based on the mean density of their neighboring hexagons.

Usage

find_low_dens_hex(model_2d, b1 = 30, md_thresh = 0.05)

Value

A vector containing the IDs of hexagons to be removed after investigating their neighboring bins.

Arguments

model_2d

The tibble that contains all hexagonal bin centroids.

b1

Number of bins along the x-axis for hexagon binning.

md_thresh

A numeric value that contains the threshold for mean density.

Examples

Run this code
find_low_dens_hex(model_2d = scurve_model_obj$model_2d, b1 = 30,
md_thresh = 0.05)

Run the code above in your browser using DataLab