powered by
This function identifies hexagons with low density based on the mean density of their neighboring hexagons.
find_low_dens_hex(model_2d, b1 = 30, md_thresh = 0.05)
A vector containing the IDs of hexagons to be removed after investigating their neighboring bins.
The tibble that contains all hexagonal bin centroids.
Number of bins along the x-axis for hexagon binning.
A numeric value that contains the threshold for mean density.
find_low_dens_hex(model_2d = scurve_model_obj$model_2d, b1 = 30, md_thresh = 0.05)
Run the code above in your browser using DataLab